==> release.dxp.api-7.3.10.1-sources.jar: com/liferay/info/constants/InfoDisplayWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.info.constants;

/**
 * @author Jürgen Kappler
 */
public class InfoDisplayWebKeys {

	public static final String INFO_DISPLAY_CONTRIBUTOR =
		"INFO_DISPLAY_CONTRIBUTOR";

	public static final String INFO_DISPLAY_CONTRIBUTOR_TRACKER =
		"INFO_DISPLAY_CONTRIBUTOR_TRACKER";

	public static final String INFO_ITEM = "INFO_ITEM";

	public static final String INFO_ITEM_DETAILS = "INFO_ITEM_DETAILS";

	public static final String INFO_ITEM_FIELD_VALUES_PROVIDER =
		"INFO_FIELD_VALUES_PROVIDER";

	public static final String INFO_ITEM_RENDERER_TRACKER =
		"INFO_ITEM_RENDERER_TRACKER";

	public static final String INFO_ITEM_SELECTOR_TRACKER =
		"INFO_ITEM_SELECTOR_TRACKER";

	public static final String INFO_ITEM_SERVICE_TRACKER =
		"INFO_ITEM_SERVICE_TRACKER";

	public static final String INFO_LIST_DISPLAY_OBJECT =
		"INFO_LIST_DISPLAY_OBJECT";

	public static final String VERSION_CLASS_PK = "VERSION_CLASS_PK";

}

==> release.dxp.api-7.4.13-sources.jar: com/liferay/info/constants/InfoDisplayWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.info.constants;

/**
 * @author Jürgen Kappler
 */
public class InfoDisplayWebKeys {

	public static final String INFO_DISPLAY_CONTRIBUTOR =
		"INFO_DISPLAY_CONTRIBUTOR";

	public static final String INFO_DISPLAY_CONTRIBUTOR_TRACKER =
		"INFO_DISPLAY_CONTRIBUTOR_TRACKER";

	public static final String INFO_ITEM = "INFO_ITEM";

	public static final String INFO_ITEM_DETAILS = "INFO_ITEM_DETAILS";

	public static final String INFO_ITEM_FIELD_VALUES_PROVIDER =
		"INFO_FIELD_VALUES_PROVIDER";

	public static final String INFO_ITEM_RENDERER_TRACKER =
		"INFO_ITEM_RENDERER_TRACKER";

	public static final String INFO_ITEM_SELECTOR_TRACKER =
		"INFO_ITEM_SELECTOR_TRACKER";

	public static final String INFO_ITEM_SERVICE_TRACKER =
		"INFO_ITEM_SERVICE_TRACKER";

	public static final String INFO_LIST_DISPLAY_OBJECT =
		"INFO_LIST_DISPLAY_OBJECT";

	public static final String INFO_LIST_DISPLAY_OBJECT_ITEM_TYPE =
		"INFO_LIST_DISPLAY_OBJECT_ITEM_TYPE";

	public static final String VERSION_CLASS_PK = "VERSION_CLASS_PK";

}
